@@ -439,7 +439,7 @@ class MultiGridDataSeries(GridDataSeries):
         """hdf5ファイルを閉じる.
         """
         for data in self.series:
-            series.h5.close()
+            self.series.h5.close()
 
     def time_series(self, x, y, z):
         """指定した範囲の時系列データを取得する.
@@ -1055,7 +1055,7 @@ class Data4d(Data):
 
         return super().__new__(cls, input_array, **kwargs)
 
-    def plot(mode='auto', **kwargs):
+    def plot(self, mode='auto', **kwargs):
         """3次元データをプロットする.(未実装)
 
         Parameters
@@ -1087,7 +1087,7 @@ class Data3d(Data):
 
         return super().__new__(cls, input_array, **kwargs)
 
-    def plot(mode='auto', **kwargs):
+    def plot(self, mode='auto', **kwargs):
         """3次元データをプロットする.(未実装)
 
         Parameters
@@ -1254,13 +1254,19 @@ class Data2d(Data):
                 y = _offseted(y, offsets[1])
                 z = _offseted(z, offsets[2])
             mesh = np.meshgrid(x, y)
-            
+
             imgs = []
-            if 'cm' in mode:
+            if 'cm' in mode and 'cont' in mode:
+                savefilename = kwargs.get('savefilename', None)
+                kwargs['savefilename'] = None
+                img = emplt.plot_2dmap(z, mesh=mesh, **kwargs)
+                kwargs['savefilename'] = savefilename
+                img2 = emplt.plot_2d_contour(z, mesh=mesh, **kwargs)
+                imgs = [img, img2]
+            elif 'cm' in mode:
                 img = emplt.plot_2dmap(z, mesh=mesh, **kwargs)
                 imgs.append(img)
-
-            if 'cont' in mode:
+            elif 'cont' in mode:
                 img = emplt.plot_2d_contour(z, mesh=mesh, **kwargs)
                 imgs.append(img)
 
