@@ -1,4 +1,4 @@
 from .emsesinp import UnitConversionKey, InpFile
-from .units import Units
+from .units import Units, UnitTranslator
 from .util import *
 from .group import Group
